savedcmd_scripts/generate_rust_target := rustc --out-dir scripts/ --emit=dep-info=scripts/.generate_rust_target.d -Clinker-flavor=gcc -Clinker=gcc -Clink-args=' ' --edition=2021 -Zbinary_dep_depinfo=y -Astable_features -Aunused_features -Dnon_ascii_idents -Dunsafe_op_in_unsafe_fn -Wmissing_docs -Wrust_2018_idioms -Wunreachable_pub -Wclippy::all -Aclippy::collapsible_if -Aclippy::collapsible_match -Wclippy::ignored_unit_patterns -Wclippy::mut_mut -Wclippy::needless_bitwise_bool -Aclippy::needless_lifetimes -Wclippy::no_mangle_with_rust_abi -Wclippy::undocumented_unsafe_blocks -Aclippy::uninlined_format_args -Wclippy::unnecessary_safety_comment -Wclippy::unnecessary_safety_doc -Wrustdoc::missing_crate_level_docs -Wrustdoc::unescaped_backticks -O -Cstrip=debuginfo -Zallow-features=    --emit=link=scripts/generate_rust_target scripts/generate_rust_target.rs

source_scripts/generate_rust_target := scripts/generate_rust_target.rs

deps_scripts/generate_rust_target := \
    $(wildcard include/config/RUSTC_VERSION) \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libstd-409c26d5a19aa7ae.so \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libstd-409c26d5a19aa7ae.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libstd-409c26d5a19aa7ae.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libcore-921b00669000b262.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libcore-921b00669000b262.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/liballoc-3cf3abd8e2fb6ed2.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/liballoc-3cf3abd8e2fb6ed2.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libcompiler_builtins-5450ba9835df1d55.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libcompiler_builtins-5450ba9835df1d55.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/liblibc-9fcedee9de5949fe.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/liblibc-9fcedee9de5949fe.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/librustc_std_workspace_core-c94d1a27448ea7bd.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/librustc_std_workspace_core-c94d1a27448ea7bd.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libunwind-589b1954ab6e86ae.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libunwind-589b1954ab6e86ae.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libminiz_oxide-6949d4af79f44156.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libminiz_oxide-6949d4af79f44156.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libadler2-accaa76e758324ed.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libadler2-accaa76e758324ed.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libhashbrown-22b235243608867c.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libhashbrown-22b235243608867c.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/librustc_std_workspace_alloc-53eaffb2801fd0a4.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/librustc_std_workspace_alloc-53eaffb2801fd0a4.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libstd_detect-66f869149090742a.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libstd_detect-66f869149090742a.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/librustc_demangle-9e6d0889f0b6335e.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/librustc_demangle-9e6d0889f0b6335e.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libcfg_if-05d673bbb25ea2fa.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libcfg_if-05d673bbb25ea2fa.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libaddr2line-ba3dddf477505a5d.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libaddr2line-ba3dddf477505a5d.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libgimli-05186a00f54cbf88.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libgimli-05186a00f54cbf88.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libobject-7f551f987cb3ebac.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libobject-7f551f987cb3ebac.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libmemchr-911b440fbd0ace07.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libmemchr-911b440fbd0ace07.rmeta \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libpanic_unwind-1af536bc43ec6359.rlib \
  /usr/lib/rustlib/x86_64-unknown-linux-gnu/lib/libpanic_unwind-1af536bc43ec6359.rmeta \

scripts/generate_rust_target: $(deps_scripts/generate_rust_target)

$(deps_scripts/generate_rust_target):
